@@ -501,6 +501,10 @@ Exportar los datos en la pestaña actual a un archivo</translation>
         <source>Fee:</source>
         <translation>Comisión:</translation>
     </message>
+    <message>
+        <source>Dust:</source>
+        <translation>Polvo:</translation>
+    </message>
     <message>
         <source>After Fee:</source>
         <translation>Después de comisión:</translation>
@@ -509,6 +513,10 @@ Exportar los datos en la pestaña actual a un archivo</translation>
         <source>Change:</source>
         <translation>Cambio:</translation>
     </message>
+    <message>
+        <source>(un)select all</source>
+        <translation>(de)seleccionar todo</translation>
+    </message>
     <message>
         <source>Tree mode</source>
         <translation>Modo árbol</translation>
@@ -581,6 +589,10 @@ Exportar los datos en la pestaña actual a un archivo</translation>
         <source>Copy bytes</source>
         <translation>Copiar bytes</translation>
     </message>
+    <message>
+        <source>Copy dust</source>
+        <translation>Copiar polvo</translation>
+    </message>
     <message>
         <source>Copy change</source>
         <translation>Copiar cambio</translation>
@@ -593,6 +605,10 @@ Exportar los datos en la pestaña actual a un archivo</translation>
         <source>no</source>
         <translation>no</translation>
     </message>
+    <message>
+        <source>This label turns red if any recipient receives an amount smaller than the current dust threshold.</source>
+        <translation>Está etiqueta se vuelve roja si algún receptor recibe una cantidad inferior al límite actual establecido para el polvo.</translation>
+    </message>
     <message>
         <source>(no label)</source>
         <translation>(no etiqueta)</translation>
@@ -1630,14 +1646,6 @@ Exportar los datos en la pestaña actual a un archivo</translation>
         <source>&amp;Request payment</source>
         <translation>Solicitar pago</translation>
     </message>
-    <message>
-        <source>Bech32 addresses (BIP-173) are cheaper to spend from and offer better protection against typos. When unchecked a P2SH wrapped SegWit address will be created, compatible with older wallets.</source>
-        <translation>Las direcciones Bech32 (BIP-173) son más baratas para gastar y ofrecen una mejor protección contra los errores tipográficos. Cuando no se selecciona, se creará una dirección SegWit envuelta en P2SH, compatible con monederos más antiguos.</translation>
-    </message>
-    <message>
-        <source>Generate Bech32 address</source>
-        <translation>Generar dirección Bech32</translation>
-    </message>
     <message>
         <source>Show the selected request (does the same as double clicking an entry)</source>
         <translation>Mostrar la solicitud seleccionada (hace lo mismo que hacer doble clic en una entrada)</translation>
@@ -1751,6 +1759,10 @@ Exportar los datos en la pestaña actual a un archivo</translation>
         <source>Clear all fields of the form.</source>
         <translation>Borre todos los campos del formulario.</translation>
     </message>
+    <message>
+        <source>Dust:</source>
+        <translation>Polvo:</translation>
+    </message>
     <message>
         <source>Copy quantity</source>
         <translation>Cantidad de copia</translation>
@@ -1772,6 +1784,10 @@ Tarifa de copia</translation>
         <source>Copy bytes</source>
         <translation>Copiar bytes</translation>
     </message>
+    <message>
+        <source>Copy dust</source>
+        <translation>Copiar polvo</translation>
+    </message>
     <message>
         <source>Copy change</source>
         <translation>Copiar cambio</translation>
@@ -1910,6 +1926,10 @@ Exportar los datos en la pestaña actual a un archivo</translation>
         <source>Litecoin Core</source>
         <translation>Litecoin Core</translation>
     </message>
+    <message>
+        <source>This is the transaction fee you may discard if change is smaller than dust at this level</source>
+        <translation>Esta es la cuota de transacción que puede descartar si el cambio es más pequeño que el polvo a este nivel.</translation>
+    </message>
     <message>
         <source>Information</source>
         <translation>Información</translation>
